@@ -1,12 +1,11 @@
 #' Get the EOL ID from Encyclopedia of Life from taxonomic names.
 #' 
-#' Note that EOL doesn't expose an API endpointn for directly querying for EOL
+#' Note that EOL doesn't expose an API endpoint for directly querying for EOL
 #' taxon ID's, so we first use the function \code{\link[taxize]{eol_search}} to find pages
 #' that deal with the species of interest, then use \code{\link[taxize]{eol_pages}}
 #' to find the actual taxon IDs. 
 #' 
 #' @import plyr RCurl
-#' @importFrom reshape sort_df
 #' @param sciname character; scientific name.
 #' @param ask logical; should get_eolid be run in interactive mode? 
 #' If TRUE and more than one ID is found for the species, the user is asked for 
@@ -26,45 +25,64 @@
 #' @author Scott Chamberlain, \email{myrmecocystus@@gmail.com}
 #' 
 #' @examples \dontrun{
-#' get_eolid(sciname='Poa annua')
 #' get_eolid(sciname='Pinus contorta')
 #' get_eolid(sciname='Puma concolor')
 #' 
-#' get_eolid(c("Poa annua", "Pinus contorta"))
+#' get_eolid(c("Puma concolor", "Pinus contorta"))
 #' 
 #' # When not found
 #' get_eolid(sciname="uaudnadndj")
 #' get_eolid(c("Chironomus riparius", "uaudnadndj"))
 #' }
+
 get_eolid <- function(sciname, ask = TRUE, verbose = TRUE, key = NULL, ...){
   fun <- function(sciname, ask, verbose) {
     mssg(verbose, "\nRetrieving data for taxon '", sciname, "'\n")
     tmp <- eol_search(terms = sciname, key, ...)
     
+    ms <- "Not found. Consider checking the spelling or alternate classification"
+    datasource <- NA
     if(all(is.na(tmp))){
-      mssg(verbose, "Not found. Consider checking the spelling or alternate classification")
+      mssg(verbose, ms)
       id <- NA
     } else {   
       pageids <- tmp[grep(tolower(sciname), tolower(tmp$name)), "pageid"]
-      dfs <- compact(lapply(pageids, function(x) eol_pages(x)$scinames))
-      dfs <- ldply(dfs[!sapply(dfs, nrow)==0])
-      df <- dfs[,c('identifier','scientificname','nameaccordingto')]
-      names(df) <- c('eolid','name','source')
-      df <- getsourceshortnames(df)
       
-      if(nrow(df) == 0){
-        mssg(verbose, "Not found. Consider checking the spelling or alternate classification")
+      if(length(pageids) == 0){
+        if(nrow(tmp)>0)
+        mssg(verbose, paste(ms, sprintf('\nDid find: %s', paste(tmp$name, collapse = "; "))))
         id <- NA
-      } else{ 
-        id <- df$eolid 
+      } else
+      {
+        dfs <- lapply(pageids, function(x) eol_pages(x)$scinames)
+        names(dfs) <- pageids
+        dfs <- taxize_compact(dfs)
+        if(length(dfs)>1) dfs <- dfs[!sapply(dfs, nrow)==0]
+        dfs <- ldply(dfs)
+        df <- dfs[,c('.id','identifier','scientificname','nameaccordingto')]
+        names(df) <- c('pageid','eolid','name','source')
+        df <- getsourceshortnames(df)
+        
+        if(nrow(df) == 0){
+          mssg(verbose, ms)
+          id <- NA
+        } else{ 
+          id <- df$eolid 
+        }
+        names(id) <- df$pageid
       }
     }
 
     # not found on eol
     if(length(id) == 0){
-      message("Not found. Consider checking the spelling or alternate classification")
+      mssg(verbose, ms)
       id <- NA
     }
+    # only one found on eol
+    if(length(id) == 1 & !all(is.na(id))){
+      id <- df$eolid
+      datasource <- df$source
+    }
     # more than one found on eol -> user input
     if(length(id) > 1){
       if(ask){
@@ -82,6 +100,8 @@ get_eolid <- function(sciname, ask = TRUE, verbose = TRUE, key = NULL, ...){
           take <- as.numeric(take)
           message("Input accepted, took eolid '", as.character(df$eolid[take]), "'.\n")
           id <- as.character(df$eolid[take])
+          names(id) <- as.character(df$pageid[take])
+          datasource <- as.character(df$source[take])
         } else {
           id <- NA
           mssg(verbose, "\nReturned 'NA'!\n\n")
@@ -90,10 +110,23 @@ get_eolid <- function(sciname, ask = TRUE, verbose = TRUE, key = NULL, ...){
         id <- NA
       }
     }  
-    return(id)
+    
+    id_source <- list(id=id, source=datasource)
+    return( id_source )
   }
-  out <- laply(sciname, fun, ask, verbose)
-  class(out) <- "eolid"
+  sciname <- as.character(sciname)
+  out <- lapply(sciname, fun, ask, verbose)
+  justids <- sapply(out, "[[", "id")
+  justsources <- sapply(out, "[[", "source")
+  class(justids) <- "eolid"
+  s_pids <- names(justids)
+  out <- unname(justids)
+  if(!is.na(justids[1])){
+    s_pids <- s_pids[vapply(s_pids, nchar, 1) > 0]
+    attr(out, 'uri') <- 
+      sprintf('http://eol.org/pages/%s/overview', s_pids)
+  }
+  attr(out, 'provider') <- justsources
   return(out)
 }
 
@@ -105,6 +138,13 @@ getsourceshortnames <- function(input){
                            'NCBI Taxonomy',
                            'IUCN Red List (Species Assessed for Global Conservation)'))
   bb <- merge(input, lookup, by.x="source", by.y="b")[,-1]
-  names(bb)[3] <- "source"
-  sort_df(bb, "name")
+  names(bb)[4] <- "source"
+  taxize_sort_df(bb, "name")
+}
+
+taxize_sort_df <- function (data, vars = names(data)) 
+{
+  if (length(vars) == 0 || is.null(vars)) 
+    return(data)
+  data[do.call("order", data[, vars, drop = FALSE]), , drop = FALSE]
 }
\ No newline at end of file
