@@ -6,11 +6,15 @@
 #' @return Names or TSNs of all downstream taxa.
 #' @export
 #' @examples \dontrun{
-#' itis_acceptname(searchtsn='208527')  # TSN accepted - good name
-#' itis_acceptname(searchtsn='504239')  # TSN not accepted - input TSN is old
+#' itis_acceptname('208527')  # TSN accepted - good name
+#' itis_acceptname('504239')  # TSN not accepted - input TSN is old
 #' }
 itis_acceptname <- function(searchtsn = NA, ...)
 {
 	tt <- getacceptednamesfromtsn(searchtsn, ...)
-	if(length(tt)==1){tt} else {data.frame(tt)}
+	if(length(tt)==1){tt} else {
+    tmp <- data.frame(tt)
+    names(tmp) <- tolower(names(tmp))
+    tmp
+	}
 }
\ No newline at end of file
