@@ -23,8 +23,8 @@ itis_native <- function(tsn=NULL, what="bytsn", ...)
 {
   temp <- switch(what, 
          bytsn = lapply(tsn, function(x) getjurisdictionaloriginfromtsn(x, ...)),
-         values = getjurisdictionvalues(),
-         originvalues = getjurisdictionoriginvalues())
+         values = getjurisdictionvalues(...),
+         originvalues = getjurisdictionoriginvalues(...))
   if(length(tsn)==1){
     temp[[1]]
   } else
