@@ -11,21 +11,21 @@
 #' 		for help on how to put api keys in your .Rprofile file.
 #' @param verbose Verbose or not, logical
 #' @return data.frame of results.
+#' @export
 #' @examples \dontrun{
 #' plants <- c("Myrcia lingua", "Myrcia bella", "Ocotea pulchella", 
 #' 		"Miconia", "Coffea arabica var. amarella", "Bleh")
 #' plantminer(plants)
 #' }
-#' @export
+
 plantminer <- function(plants, key = NULL, verbose=TRUE)
 {
 	key <- getkey(key, "pmApiKey")
-	
+	  
   i <- NULL
-  compiled.list <- foreach (i=1:length(plants), .combine =
-    rbind) %do% {
+  compiled.list <- foreach (i=1:length(plants), .combine = rbind) %do% {
     full.name <- strsplit(plants[i], " ")[[1]]
-    mssg(verbose, paste(full.name))
+    mssg(verbose, paste(full.name, collapse = " "))
     genus <- full.name[1]
     if (length(full.name) > 1) {
       species <- paste(full.name[2:length(full.name)], collapse = " ")
@@ -43,5 +43,5 @@ plantminer <- function(plants, key = NULL, verbose=TRUE)
   colnames(compiled.list) <- c("fam", "genus", "sp", "author", "source",
     "source.id", "status", "confidence", "suggestion", "database")
   rownames(compiled.list) <- 1:NROW(compiled.list)
-  return(data.frame(compiled.list))
+  return( data.frame(compiled.list) )
 }
\ No newline at end of file
