@@ -2,6 +2,7 @@
 #' 
 #' Retrieve name of queried taxonomic rank of a taxon.
 #' 
+#' @export
 #' @param query character; Vector of taxonomic names to query.
 #' @param get character; The ranks of the taxonomic name to get, see 
 #' \code{\link[taxize]{rank_ref}}.
@@ -41,7 +42,7 @@
 #' tax_name(query=c("Helianthus annuus", 'Baetis rhodani'), get=c("genus", 
 #' "kingdom"), db="both")
 #' }
-#' @export
+
 tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi', 
                      verbose = TRUE, ...)
 {
@@ -57,19 +58,20 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
   fun <- function(query, get, db, verbose, ...){
     # ITIS
   	if(db == "itis"){
-  		tsn <- get_tsn(query, searchtype = "sciname", verbose = verbose, ...)
+  		tsn <- get_tsn(query, searchtype = "scientific", verbose = verbose, ...)
       if(is.na(tsn)) {
         if(verbose) 
           message("No TSN found for species '", query, "'!\n")
         out <- data.frame(t(rep(NA, length(get))))
         names(out) <- get
       } else {
-        tt <- classification(tsn, ...)[[1]]
+        tt <- classification(tsn, verbose=verbose, ...)[[1]]
         out <- as.character(tt[tolower(tt$rank) %in% tolower(get), "name"])
         if(length(out) == 0)
           out <- data.frame(t(rep(NA, length(get))))
         out <- data.frame(t(out), stringsAsFactors = FALSE)
-        names(out) <- get
+        names(out) <- tolower(as.character(tt[tolower(tt$rank) %in% tolower(get), "rank"]))
+#         names(out) <- get
       }
   	}
     
@@ -102,13 +104,13 @@ tax_name <- function(query = NULL, get = NULL, db = "itis", pref = 'ncbi',
         match_uid <- hierarchy$name[match(tolower(get), tolower(hierarchy$rank))]
       }
       # itis
-      tsn <- get_tsn(query, searchtype="sciname", verbose = verbose, ...)
+      tsn <- get_tsn(query, searchtype="scientific", verbose = verbose, ...)
       if(is.na(tsn)) {
         if(verbose) 
           message("No TSN found for species '", query, "'!\n")
         match_tsn <- rep(NA, length(get))
       } else {
-        tt <- classification(tsn)[[1]]
+        tt <- classification(tsn, verbose = verbose)[[1]]
         match_tsn <- tt$name[match(tolower(get), tolower(tt$rank))]
       }
       match_both <- ifelse(is.na(match_uid), match_tsn, match_uid)
