@@ -4,8 +4,8 @@ context("class2tree")
 # spnames <- names_list('species', 30)
 spnames <- c('Physoplexis comosa','Nidorella zavattarii','Centaurea musimomum','Portulaca striata','Cerastium candidissimum','Faramea bicolor','Garrya salicifolia','Clerodendrum curranii','Campanula khorasanica','Micropholis gardneriana','Manilkara excelsa','Fimbristylis alboviridis','Sideritis montana','Polianthes longiflora')
 spnames2 <- c('Elachanthemum intricatum','Trichocoronis wrightii','Solanum valdiviense','Ilex perado','Aristida lazaridis','Verticordia blepharophylla','Coleocephalocereus purpureus','Catasetum vinaceum','Narcissus bujei','Erigeron hyperboreus','Ceiba speciosa','Kosteletzkya grantii','Pavonia alnifolia','Saxifraga petraea','Tephrosia decaryana','Astragalus buchtormensis')
-out <- classification(spnames, db='ncbi')
-out2 <- classification(spnames2, db='ncbi')
+out <- classification(spnames, db='ncbi', verbose=FALSE)
+out2 <- classification(spnames2, db='ncbi', verbose=FALSE)
 out <- out[!is.na(out)]
 out2 <- out2[!is.na(out2)]
 # length(out)
